Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/matomo-org/matomo.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--core/Updates/4.3.0-rc2.php (renamed from core/Updates/4.3.0-b5.php)4
-rw-r--r--core/Version.php2
2 files changed, 3 insertions, 3 deletions
diff --git a/core/Version.php b/core/Version.php
index 055c1f27a4..e21c8637d8 100644
--- a/core/Version.php
+++ b/core/Version.php
@@ -20,7 +20,7 @@ final class Version
* The current Matomo version.
* @var string
*/
- const VERSION = '4.3.0-rc1';
+ const VERSION = '4.3.0-rc2';
const MAJOR_VERSION = 4;
public function isStableVersion($version)
diff --git a/core/Updates/4.3.0-b5.php b/core/Updates/4.3.0-rc2.php
index 0c6e405125..9246997727 100644
--- a/core/Updates/4.3.0-b5.php
+++ b/core/Updates/4.3.0-rc2.php
@@ -17,9 +17,9 @@ use Piwik\Db;
use Piwik\Common;
/**
* Update for version 4.3.0-b5.
*/
-class Updates_4_3_0_b5 extends PiwikUpdates
+class Updates_4_3_0_rc2 extends PiwikUpdates
{
/**
* @var MigrationFactory
@@ -17,9 +17,9 @@ use Piwik\Db;
use Piwik\Common;
/**
- * Update for version 4.3.0-b5.
+ * Update for version 4.3.0-rc2.
*/